﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using DlhSoft.Windows.Data;

namespace ResourceManagerSample
{
    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("ResourceManager Sample");

            // Prepare the resource data collection.
            ObservableCollection<ResourceItem> resourceItems = new ObservableCollection<ResourceItem>
            {
                new ResourceItem { Content = "Resource 1" },
                new ResourceItem { Content = "Resource 2", CostPerHour = 10 },
                new ResourceItem { Content = "Resource 3", CostPerUsage = 100 },
                new ResourceItem { Content = "Resource 4", CostPerUsage = 200, CostPerHour = 20 }
            };

            // You can also prepare resource data items dynamically.
            for (int i = 5; i <= 64; i++)
                resourceItems.Add(new ResourceItem { Content = "Resource " + i });

            // Initialize the ResourceManager object using the prepared resource data items.
            ResourceManager resourceManager = new ResourceManager(resourceItems);

            // Use the Resources and other properties of the ResourceManager object to access the managed resources and related information.
            Console.WriteLine("Resources: Count = {0}", resourceManager.Count);
            foreach (Resource resource in resourceManager.Resources)
                Console.WriteLine("Resources[{0}]: CostPerUsage = {1:c}, CostPerHour = {2:c}", resource.Index, resource.CostPerUsage, resource.CostPerHour);

            // Dispose the ResourceManager object when it is no longer needed.
            resourceManager.Dispose();
        }
    }
}
